:tocdepth: 2

.. _authors:

Authors
=======

Aqtinstall is written and maintained by Hiroshi Miura <miurahr@linux.com>

Original qli-installer is written by Linus Jahn

Utilize for Github Actions recipe and many feedback by Benjamin O

Contributors, listed alphabetically, are:

* Andrei Yankovich (tools ifw installation)
* Aurélien Gâteau (patching to qmake, #100)
* Gamso (improve parsing of update.xml)
* Kyle Altendorf (7z binary path search)
* Martin Delille (Document)
* Mizux Seihax (Qt versions)
* Nelson Chen (CI tests)
* pylipp (Document)
* Felix Barz (Android, Explicit extra module installation)
* Sztergbaum Roman
* Thomas Grainger (CLI entry point)
* Vadim Peretokin (Version database)
* ypnos (Document)

and many other participants and contributors.